searchData={"items":[{"type":"module","title":"RTC","doc":"RDF Triple Compounds.\n\nThis library provides the `RTC.Compound` struct for working with\nRDF Triple Compounds.\n\nSee the [RTC spec](https://w3id.org/rtc) for a general introduction into the\nvocabulary and the idea behind it and the [guide on RTC.ex](https://rdf-elixir.dev/rtc-ex/)\nfor an introduction on working with this library.","ref":"RTC.html"},{"type":"function","title":"RTC.element_of/0","doc":"","ref":"RTC.html#element_of/0"},{"type":"function","title":"RTC.element_of/1","doc":"","ref":"RTC.html#element_of/1"},{"type":"function","title":"RTC.element_of/2","doc":"","ref":"RTC.html#element_of/2"},{"type":"function","title":"RTC.elementOf/0","doc":"","ref":"RTC.html#elementOf/0"},{"type":"function","title":"RTC.elementOf/1","doc":"","ref":"RTC.html#elementOf/1"},{"type":"function","title":"RTC.elementOf/2","doc":"","ref":"RTC.html#elementOf/2"},{"type":"function","title":"RTC.elements/0","doc":"","ref":"RTC.html#elements/0"},{"type":"function","title":"RTC.elements/1","doc":"","ref":"RTC.html#elements/1"},{"type":"function","title":"RTC.elements/2","doc":"","ref":"RTC.html#elements/2"},{"type":"function","title":"RTC.id/0","doc":"","ref":"RTC.html#id/0"},{"type":"function","title":"RTC.id/1","doc":"","ref":"RTC.html#id/1"},{"type":"function","title":"RTC.sub_compound_of/0","doc":"","ref":"RTC.html#sub_compound_of/0"},{"type":"function","title":"RTC.sub_compound_of/1","doc":"","ref":"RTC.html#sub_compound_of/1"},{"type":"function","title":"RTC.sub_compound_of/2","doc":"","ref":"RTC.html#sub_compound_of/2"},{"type":"function","title":"RTC.subCompoundOf/0","doc":"","ref":"RTC.html#subCompoundOf/0"},{"type":"function","title":"RTC.subCompoundOf/1","doc":"","ref":"RTC.html#subCompoundOf/1"},{"type":"function","title":"RTC.subCompoundOf/2","doc":"","ref":"RTC.html#subCompoundOf/2"},{"type":"module","title":"RTC.Compound","doc":"A struct representing an RDF Triple Compound.\n\nAn RDF Triple Compound is a set of triples embedded in an RDF graph.\n\nYou can create such a set of triples either from scratch with the `new/1`\nfunction, or you can load an already existing compound from an RDF graph with\nthe `from_rdf/2` function.\n\nYou can then use the various functions on this module to get its triples,\nsub-compounds, super-compounds and annotations or edit them.\n\nFinally, you can get back the RDF form of the compound with `to_rdf/2`.\nIf you only want an RDF graph of the contained triples (without the annotations),\nyou can use the `graph/1` function.","ref":"RTC.Compound.html"},{"type":"module","title":"Asserted and unasserted triples - RTC.Compound","doc":"A compound can contain both asserted and unasserted triples. When creating a\ncompound with initial triples with the `new/3` function or adding triples with\n`add/3` you can specify in which assertion mode the given triples should be\ninterpreted with the `:assertion_mode` option and one of the values `:asserted`\nor `:unasserted`. By default, `:asserted` is assumed, but you can configure the\ndefault value in your application with the following configuration\non your `config.exs` files:\n\n    config :rtc, :assertion_mode, :unasserted\n\nAll query functions operating over the set of triples and the `delete/3`\nand `delete_description/3` functions also support an `:assertion_mode` which\ndefines which triples should be considered with the following supported\nvalues:\n\n- `:all` (default): consider both asserted and unasserted triples\n- `:asserted`: only consider asserted triples\n- `:unasserted`: only consider unasserted triples","ref":"RTC.Compound.html#module-asserted-and-unasserted-triples"},{"type":"module","title":"Auto-generated ids - RTC.Compound","doc":"Various functions can be used in such a way, that they will create compounds with\na proper resource identifier implicitly. By default, they will create a random blank\nnode, but the identifier creation behavior can be configured and customized via\n`RDF.Resource.Generator`s.\nFor example, to create UUIDv4 URIs instead, you could use this configuration in your\n`config.exs`:\n\n    config :rtc, :id,\n      generator: RDF.IRI.UUID.Generator,\n      uuid_version: 4,\n      prefix: \"http://example.com/ns/\"\n\nSee [the guide on resource generators](https://rdf-elixir.dev/rdf-ex/resource-generators.html)\nfor more information and available generators.","ref":"RTC.Compound.html#module-auto-generated-ids"},{"type":"function","title":"RTC.Compound.add/3","doc":"Adds `triples` to the given `compound`.\n\nTriples can be provided in any form accepted by `RDF.Graph.add/2`.\n\nAvailable options:\n\n- `:assertion_mode`: the assertion mode to be used for the `triples` to be added\n  (see module documentation section on \"Asserted and unasserted triples\")","ref":"RTC.Compound.html#add/3"},{"type":"function","title":"RTC.Compound.add_annotations/2","doc":"Adds statements to the annotations of the given `compound`.","ref":"RTC.Compound.html#add_annotations/2"},{"type":"function","title":"RTC.Compound.annotations/2","doc":"Returns the annotations of the given `compound`.\n\nSupported options:\n\n- `:inherited` - controls if inherited annotations should be included or\n  only the direct annotations of the given compound should be returned.\n  Default: `true`","ref":"RTC.Compound.html#annotations/2"},{"type":"function","title":"RTC.Compound.asserted_graph/2","doc":"Returns an RDF graph of the asserted triples in the compound (incl. its sub-compounds) without the annotations.\n\nThe following options can be used to customize the returned graph:\n\n- `:name`: the name of the graph to be created\n  (by default, the compound id is used as the graph name, unless a blank node is used\n  as the compound id, or the one specified with `:name` on `new/3`)\n- `:prefixes`: some prefix mappings which should be added the graph\n  and will be used for example when serializing in a format with prefix support.\n  Defaults to the ones specified during the creation of the compound with `new/3`.\n- `:base_iri`: a base IRI which should be stored alongside the graph\n  and will be used for example when serializing in a format with base IRI support","ref":"RTC.Compound.html#asserted_graph/2"},{"type":"function","title":"RTC.Compound.change_graph_name/2","doc":"Sets a new graph name on the given `compound` that will be used in serializations to RDF.","ref":"RTC.Compound.html#change_graph_name/2"},{"type":"function","title":"RTC.Compound.change_name/2","doc":"","ref":"RTC.Compound.html#change_name/2"},{"type":"function","title":"RTC.Compound.default_assertion_mode/0","doc":"Returns the default value of the `:assertion_mode` option.\n\nThis value can be configured in your application with the following configuration\non your `config.exs` files:\n\n    config :rtc, :assertion_mode, :unasserted\n\nWhen no `:assertion_mode` is specified, the `:asserted` style is used by default.","ref":"RTC.Compound.html#default_assertion_mode/0"},{"type":"function","title":"RTC.Compound.default_element_style/0","doc":"Returns the default value of the `:element_style` option of `to_rdf/2`.\n\nThis value can be configured in your application with the following configuration\non your `config.exs` files:\n\n    config :rtc, :element_style, :elements\n\nWhen no `:element_style` is specified, the `:element_of` style is used by default.","ref":"RTC.Compound.html#default_element_style/0"},{"type":"function","title":"RTC.Compound.delete/3","doc":"Deletes `triples` from the given `compound`.\n\nTriples can be provided in any form accepted by `RDF.Graph.delete/2`.\n\nIf a triple occurs in one or more sub-compounds, it gets deleted from all of them.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#delete/3"},{"type":"function","title":"RTC.Compound.delete_annotations/2","doc":"Deletes statements from the annotations of the given `compound`.\n\nStatements not part of the annotations are simply ignored.","ref":"RTC.Compound.html#delete_annotations/2"},{"type":"function","title":"RTC.Compound.delete_descriptions/3","doc":"Deletes all triples with the given `subjects` from the given `compound`.\n\nIf a triple occurs in one or more sub-compounds, it gets deleted from all of them.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#delete_descriptions/3"},{"type":"function","title":"RTC.Compound.delete_sub_compound/2","doc":"Deletes a sub-compound from the given `compound`.\n\nThe `sub_compound` to be deleted can be specified by id or given directly.\nNote however, that the elements of the sub-compound to be deleted are not\ntaken into consideration, just its id is used to address the sub-compound\nto be deleted.","ref":"RTC.Compound.html#delete_sub_compound/2"},{"type":"function","title":"RTC.Compound.delete_super_compound/2","doc":"Deletes a super-compound from the given `compound`.\n\nThe `super_compound` to be deleted can be specified by id or given directly.\nNote however, that the elements of the super-compound to be deleted are not\ntaken into consideration, just its id is used to address the super-compound\nto be deleted.","ref":"RTC.Compound.html#delete_super_compound/2"},{"type":"function","title":"RTC.Compound.describes?/3","doc":"Returns whether the given `compound` or any of its sub-compounds contains triples about the given subject.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#describes?/3"},{"type":"function","title":"Examples - RTC.Compound.describes?/3","doc":"iex> RTC.Compound.new([{EX.S1, EX.p1, EX.O1}]) |> RTC.Compound.describes?(EX.S1)\n    true\n\n    iex> RTC.Compound.new([{EX.S1, EX.p1, EX.O1}]) |> RTC.Compound.describes?(EX.S2)\n    false","ref":"RTC.Compound.html#describes?/3-examples"},{"type":"function","title":"RTC.Compound.description/3","doc":"Returns the description of the given subject.\n\nWhen the subject can not be found an empty description is returned.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#description/3"},{"type":"function","title":"Examples - RTC.Compound.description/3","doc":"iex> RTC.Compound.new([{EX.S1, EX.P1, EX.O1}, {EX.S2, EX.P2, EX.O2}])\n    ...> |> RTC.Compound.description(EX.S1)\n    RDF.Description.new(EX.S1, init: {EX.P1, EX.O1})\n\n    iex> RTC.Compound.new([{EX.S, EX.P1, EX.O1}], sub_compounds: RTC.Compound.new([{EX.S, EX.P2, EX.O2}]))\n    ...> |> RTC.Compound.description(EX.S)\n    RDF.Description.new(EX.S, init: [{EX.P1, EX.O1}, {EX.P2, EX.O2}])\n\n    iex> RTC.Compound.new([])\n    ...> |> RTC.Compound.description(EX.S1)\n    RDF.Description.new(EX.S1)","ref":"RTC.Compound.html#description/3-examples"},{"type":"function","title":"RTC.Compound.descriptions/2","doc":"Returns a list of the `RDF.Description`s in the given `compound`.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#descriptions/2"},{"type":"function","title":"RTC.Compound.empty?/2","doc":"Returns if the given `compound` (and of its sub-compounds) does not contain any triples.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#empty?/2"},{"type":"function","title":"RTC.Compound.fetch/3","doc":"Fetches the description of the given subject.\n\nWhen the subject can not be found `:error` is returned.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#fetch/3"},{"type":"function","title":"Examples - RTC.Compound.fetch/3","doc":"iex> RTC.Compound.new([{EX.S1, EX.P1, EX.O1}, {EX.S2, EX.P2, EX.O2}], EX.Compound)\n    ...> |> RTC.Compound.fetch(EX.S1)\n    {:ok, RDF.Description.new(EX.S1, init: {EX.P1, EX.O1})}\n\n    iex> RTC.Compound.new() |> RTC.Compound.fetch(EX.foo)\n    :error","ref":"RTC.Compound.html#fetch/3-examples"},{"type":"function","title":"RTC.Compound.from_rdf/2","doc":"Retrieves the compound with the given `compound_id` from a `RDF.Graph`.\n\nWhen no compound with the given `compound_id` can be found in the given\n`graph`, an empty compound is returned.","ref":"RTC.Compound.html#from_rdf/2"},{"type":"function","title":"RTC.Compound.from_sparql/2","doc":"Retrieves the compound with the given `compound_id` from a SPARQL endpoint.\n\nThis function is only available when the `sparql_client` dependency is\nadded in your `Mixfile`.\n\nWhen no compound with the given `compound_id` can be found in the given\n`graph`, an empty compound is returned.\n\nThis function requests the execution of a SPARQL `CONSTRUCT` query without any\nfurther options on the respective `SPARQL.Client` call. You can configure the\noptions to be used on this request with the `:from_sparql_opts` configuration\non your `config.exs` files, e.g.\n\n    config :rtc, :from_sparql_opts,\n        accept_header: \"application/x-turtlestar\",\n        result_format: :turtle\n\nSee `SPARQL.Client` for available options.","ref":"RTC.Compound.html#from_sparql/2"},{"type":"function","title":"RTC.Compound.from_sparql/3","doc":"Retrieves the compound with the given `compound_id` from a SPARQL endpoint.\n\nThis function is only available when the `sparql_client` dependency is\nadded in your `Mixfile`.\n\nThe `opts` are used as the options for the `CONSTRUCT` query call by the\n`SPARQL.Client` against the endpoint. See `SPARQL.Client` for\navailable options.\n\nWhen no compound with the given `compound_id` can be found in the given\n`graph`, an empty compound is returned.","ref":"RTC.Compound.html#from_sparql/3"},{"type":"function","title":"RTC.Compound.from_sparql!/3","doc":"Retrieves the compound with the given `compound_id` from a SPARQL endpoint.\n\nAs opposed to `from_sparql/3` this function returns the result directly and\nraises an error when the SPARQL client call fails.","ref":"RTC.Compound.html#from_sparql!/3"},{"type":"function","title":"RTC.Compound.get/4","doc":"Gets the description of the given `subject`.\n\nWhen the subject can not be found the optionally given default value or\n`nil` is returned.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#get/4"},{"type":"function","title":"Examples - RTC.Compound.get/4","doc":"iex> RTC.Compound.new([{EX.S1, EX.P1, EX.O1}, {EX.S2, EX.P2, EX.O2}], EX.Compound)\n    ...> |> RTC.Compound.get(EX.S1)\n    RDF.Description.new(EX.S1, init: {EX.P1, EX.O1})\n\n    iex> RTC.Compound.get(RTC.Compound.new(), EX.Foo)\n    nil\n\n    iex> RTC.Compound.get(RTC.Compound.new(), EX.Foo, :bar)\n    :bar","ref":"RTC.Compound.html#get/4-examples"},{"type":"function","title":"RTC.Compound.graph/2","doc":"Returns an RDF graph of all the asserted and unasserted triples in the compound (incl. its sub-compounds) without the annotations.\n\nThe following options can be used to customize the returned graph:\n\n- `:name`: the name of the graph to be created\n  (by default, the compound id is used as the graph name, unless a blank node is used\n  as the compound id, or the one specified with `:name` on `new/3`)\n- `:prefixes`: some prefix mappings which should be added the graph\n  and will be used for example when serializing in a format with prefix support.\n  Defaults to the ones specified during the creation of the compound with `new/3`.\n- `:base_iri`: a base IRI which should be stored alongside the graph\n  and will be used for example when serializing in a format with base IRI support\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#graph/2"},{"type":"function","title":"RTC.Compound.id/1","doc":"Returns the id of the given `compound`.","ref":"RTC.Compound.html#id/1"},{"type":"function","title":"RTC.Compound.include?/3","doc":"Returns whether the given triples are an element of the given `compound` or any of its sub-compounds.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#include?/3"},{"type":"function","title":"RTC.Compound.inherited_annotations/1","doc":"Returns the merged annotations of all super-compounds of the given `compound`.","ref":"RTC.Compound.html#inherited_annotations/1"},{"type":"function","title":"RTC.Compound.inherited_annotations/2","doc":"Returns the annotations of the given super-compound of `compound`.","ref":"RTC.Compound.html#inherited_annotations/2"},{"type":"function","title":"RTC.Compound.name/1","doc":"","ref":"RTC.Compound.html#name/1"},{"type":"function","title":"RTC.Compound.new/0","doc":"Creates a empty compound with an automatically generated id.\n\nSee the module documentation for information on auto-generated ids.","ref":"RTC.Compound.html#new/0"},{"type":"function","title":"RTC.Compound.new/1","doc":"Creates a compound with the given set of triples and an automatically generated id.\n\nIf you want to define the id yourself, use `new/2` or `new/3`.\nSee the module documentation for information on auto-generated ids.\n\nTriples can be provided in any form accepted by `RDF.Graph.new/2`.\nWhen a list of triples is given which contains nested lists of triples,\nsub-compounds with auto-generated ids are generated and added for each\nof the nested lists.","ref":"RTC.Compound.html#new/1"},{"type":"function","title":"RTC.Compound.new/2","doc":"Creates a new compound with the given set of triples and the given id.\n\nTriples can be provided in any form accepted by `RDF.Graph.new/2`.\nWhen a list of triples is given which contains nested lists of triples,\nsub-compounds with auto-generated ids are generated and added for each\nof the nested lists.\n\nIf a keyword list is given as the second argument, an id is generated and\ndelegated to `new/3`. See `new/3` for a description of the available options.\nSee the module documentation for information on auto-generated ids.","ref":"RTC.Compound.html#new/2"},{"type":"function","title":"RTC.Compound.new/3","doc":"Creates a new compound with the given set of triples and the given id.\n\nTriples can be provided in any form accepted by `RDF.Graph.new/2`.\nWhen a list of triples is given which contains nested lists of triples,\nsub-compounds with auto-generated ids are generated and added for each\nof the nested lists.\nAlternatively, the `sub_compounds` option can be used to provide one or\na list of sub-compounds to be added.\n\nAvailable options:\n\n- `:assertion_mode`: the assertion mode to be used for the `triples` to be added\n  (see module documentation section on \"Asserted and unasserted triples\")\n- `:name`: the name of the graph which gets returned by `graph/1` and\n  `to_rdf/2` (by default, the compound id is used as the graph name or `nil`\n  when the compound id is a blank node)\n- `:prefixes`: the prefix mappings which should used by default when an `RDF.Graph`\n  is produced from this compound, e.g. with `to_rdf/2`, `graph/2` etc.\n  Note, that a `rtc` prefix for the RTC vocabulary is added by `to_rdf/2` in\n  any case, so it usually not required to be defined here, unless you want it\n  to be added also to the graphs with the element triples like `graph/2`.\n- `:base_iri`: a base IRI which should be stored alongside the graph\n  and will be used for example when serializing in a format with base IRI support\n- `:annotations`: allows to set the initial annotations of the compound\n   as an `RDF.Description` or anything an `RDF.Description` can be built\n   from. The subject in the input is ignored, so that the `RDF.Description`\n   of any resource can be used as a blueprint.\n- `:sub_compounds`: a single sub-compound or multiple sub-compounds as a list\n- `:super_compounds`: a single compound id of a super-compound or multiple\n  compound ids as a list. One or multiple compounds or `RDF.Description`s of the\n  annotations can be provided also, in which case only the ids and the annotations\n  are stored.","ref":"RTC.Compound.html#new/3"},{"type":"function","title":"RTC.Compound.objects/2","doc":"The set of all resources used in the objects of the triples within a `RTC.Compound` or any of its sub-compounds.\n\nNote: This function does collect only IRIs and BlankNodes, not Literals.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#objects/2"},{"type":"function","title":"Examples - RTC.Compound.objects/2","doc":"iex> RTC.Compound.new([\n    ...>   {EX.S1, EX.p1, EX.O1},\n    ...>   {EX.S2, EX.p2, EX.O2},\n    ...>   {EX.S3, EX.p1, EX.O2},\n    ...>   {EX.S4, EX.p2, RDF.bnode(:bnode)},\n    ...>   {EX.S5, EX.p3, \"foo\"}],\n    ...>   EX.Compound)\n    ...> |> RTC.Compound.objects()\n    MapSet.new([RDF.iri(EX.O1), RDF.iri(EX.O2), RDF.bnode(:bnode)])","ref":"RTC.Compound.html#objects/2-examples"},{"type":"function","title":"RTC.Compound.pop/1","doc":"Pops an arbitrary triple from the given `compound` or any of its sub-compounds.","ref":"RTC.Compound.html#pop/1"},{"type":"function","title":"RTC.Compound.pop/3","doc":"Pops the description of the given subject.\n\nRemoves the description of the given `subject` from `compound` and\nall of its sub-compounds.\n\nReturns a tuple containing the description of the given subject\nand the updated compound without this description.\n`nil` is returned instead of the description if `compound` does\nnot contain a description of the given `subject`.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#pop/3"},{"type":"function","title":"Examples - RTC.Compound.pop/3","doc":"iex> RTC.Compound.new([{EX.S1, EX.P1, EX.O1}, {EX.S2, EX.P2, EX.O2}], EX.Compound)\n    ...> |> RTC.Compound.pop(EX.S1)\n    {\n      RDF.Description.new(EX.S1, init: {EX.P1, EX.O1}),\n      RTC.Compound.new({EX.S2, EX.P2, EX.O2}, EX.Compound)\n    }\n\n    iex> RTC.Compound.new({EX.S, EX.P, EX.O}, EX.Compound)\n    ...> |> RTC.Compound.pop(EX.Missing)\n    {nil, RTC.Compound.new({EX.S, EX.P, EX.O}, EX.Compound)}","ref":"RTC.Compound.html#pop/3-examples"},{"type":"function","title":"RTC.Compound.predicates/2","doc":"The set of all properties used in the triples within a `RTC.Compound` or any of its sub-compounds.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#predicates/2"},{"type":"function","title":"Examples - RTC.Compound.predicates/2","doc":"iex> RTC.Compound.new([\n    ...>   {EX.S1, EX.p1, EX.O1},\n    ...>   {EX.S2, EX.p2, EX.O2},\n    ...>   {EX.S1, EX.p2, EX.O3}],\n    ...>   EX.Compound)\n    ...> |> RTC.Compound.predicates()\n    MapSet.new([EX.p1, EX.p2])","ref":"RTC.Compound.html#predicates/2-examples"},{"type":"function","title":"RTC.Compound.put_sub_compound/2","doc":"Adds a sub-compound to the given `compound`.\n\nIf a sub-compound with the same id already exists, it gets overwritten.\n\nWhen just triples are passed instead of compound, a compound with an\nauto-generated id is created implicitly.","ref":"RTC.Compound.html#put_sub_compound/2"},{"type":"function","title":"RTC.Compound.put_super_compound/2","doc":"Adds a super-compound to the given `compound`.\n\nThe super-compound can be given as a compound identifier, a `RDF.Description` or a\n`RTC.Compound`. In case of a compound  only its id and annotations are relevant, which\nwill be returned when inherited annotations are requested. A `RDF.Description` is\ninterpreted as the annotations of the super-compound.\n\n> #### Warning {: .warning}\n>\n> The annotations are just used for the purpose of showing inherited annotations.\n> They won't be rendered in `to_rdf/2`. So, you can't use this function to change the\n> annotations of super-compounds.\n> You'll have to load a super-compound with `from_rdf/2` and change the annotations on\n> this compound.\n\nIf a super-compound with the same id already exists, it gets overwritten.","ref":"RTC.Compound.html#put_super_compound/2"},{"type":"function","title":"RTC.Compound.reset_id/2","doc":"Sets a new id on the given `compound`.","ref":"RTC.Compound.html#reset_id/2"},{"type":"function","title":"RTC.Compound.resources/2","doc":"The set of all resources used in the triples within a `RTC.Compound` or any of its sub-compounds.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#resources/2"},{"type":"function","title":"Examples - RTC.Compound.resources/2","doc":"iex> RTC.Compound.new([\n    ...>   {EX.S1, EX.p1, EX.O1},\n    ...>   {EX.S2, EX.p1, EX.O2},\n    ...>   {EX.S2, EX.p2, RDF.bnode(:bnode)},\n    ...>   {EX.S3, EX.p1, \"foo\"}],\n    ...>   EX.Compound)\n    ...> |> RTC.Compound.resources()\n    MapSet.new([RDF.iri(EX.S1), RDF.iri(EX.S2), RDF.iri(EX.S3),\n      RDF.iri(EX.O1), RDF.iri(EX.O2), RDF.bnode(:bnode), EX.p1, EX.p2])","ref":"RTC.Compound.html#resources/2-examples"},{"type":"function","title":"RTC.Compound.statement_count/1","doc":"","ref":"RTC.Compound.html#statement_count/1"},{"type":"function","title":"RTC.Compound.statements/1","doc":"","ref":"RTC.Compound.html#statements/1"},{"type":"function","title":"RTC.Compound.sub_compound/2","doc":"Returns the sub-compound of the given `compound` with the given `sub_compound_id`.\n\nIt will search the whole sub-compound tree for the requested `sub_compound_id`\n\nIf no compound with the `sub_compound_id` can be found, `nil` is returned.","ref":"RTC.Compound.html#sub_compound/2"},{"type":"function","title":"RTC.Compound.sub_compounds/1","doc":"Returns a list of the sub-compounds of the given `compound`.","ref":"RTC.Compound.html#sub_compounds/1"},{"type":"function","title":"RTC.Compound.subjects/2","doc":"The set of all subjects used in the triples within a `RTC.Compound` or any of its sub-compounds.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#subjects/2"},{"type":"function","title":"Examples - RTC.Compound.subjects/2","doc":"iex> RTC.Compound.new([\n    ...>   {EX.S1, EX.p1, EX.O1},\n    ...>   {EX.S2, EX.p2, EX.O2},\n    ...>   {EX.S1, EX.p2, EX.O3}],\n    ...>   EX.Compound)\n    ...> |> RTC.Compound.subjects()\n    MapSet.new([RDF.iri(EX.S1), RDF.iri(EX.S2)])","ref":"RTC.Compound.html#subjects/2-examples"},{"type":"function","title":"RTC.Compound.super_compounds/1","doc":"Returns a list of the ids of the super-compounds of the given `compound`.","ref":"RTC.Compound.html#super_compounds/1"},{"type":"function","title":"Example - RTC.Compound.super_compounds/1","doc":"iex> RTC.Compound.new({EX.S, EX.p, EX.O}, EX.Compound, super_compounds: EX.SuperCompound)\n    ...> |> RTC.Compound.super_compounds()\n    [RDF.iri(EX.SuperCompound)]","ref":"RTC.Compound.html#super_compounds/1-example"},{"type":"function","title":"RTC.Compound.to_rdf/2","doc":"Creates an RDF-star graph of the given compound with all RTC annotations.\n\nThe style for how the assignments of the triples are encoded can be specified\nwith the `:element_style` keyword and one the following values:\n\n- `:element_of`: Uses the `rtc:elementOf` property to assign each of the triples\n  individually to the compound. This has the benefit that in the Turtle-star\n  serializations the [annotation syntax](https://w3c.github.io/rdf-star/cg-spec/2021-12-17.html#annotation-syntax)\n  can be used, which doesn't require repeating the assertion and is therefore\n  more compact.\n- `:elements`: Assigns the triples to the compound, by listing them as objects\n  of the inverse `rtc:elements` property. This has the benefit that the actual\n  assertion are not pervaded by annotations and the compound resource can be\n  serialized in an isolated and self-contained manner.\n\nWhen no `:element_style` is specified, the configurable result of the\n`default_element_style/0` function is used as the default.\n\nThe following options can be used to customize the returned graph:\n\n- `:name`: the name of the graph to be created. By default, the compound id is\n  used as the graph name, unless a blank node is used as the compound id,\n  or the one specified with `:name` on `new/3`.\n- `:prefixes`: some prefix mappings which should be added the graph\n  and will be used for example when serializing in a format with prefix support.\n  Defaults to the ones specified during the creation of the compound with `new/3`\n  or the `RDF.default_prefixes/0`. The `rtc` prefix for the RTC vocabulary is\n  added in any case, so it is not required to be defined here.\n- `:base_iri`: a base IRI which should be stored alongside the graph\n  and will be used for example when serializing in a format with base IRI support","ref":"RTC.Compound.html#to_rdf/2"},{"type":"function","title":"RTC.Compound.triple_count/2","doc":"Returns the number of triples in the given `compound`.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#triple_count/2"},{"type":"function","title":"RTC.Compound.triples/2","doc":"Returns a list of the triples in the given `compound`.\n\nSupported options:\n\n- `:assertion_mode`: see module documentation section on \"Asserted and unasserted triples\"","ref":"RTC.Compound.html#triples/2"},{"type":"function","title":"RTC.Compound.unasserted_graph/2","doc":"Returns an RDF graph of the unasserted triples in the compound (incl. its sub-compounds) without the annotations.\n\nThe following options can be used to customize the returned graph:\n\n- `:name`: the name of the graph to be created\n  (by default, the compound id is used as the graph name, unless a blank node is used\n  as the compound id, or the one specified with `:name` on `new/3`)\n- `:prefixes`: some prefix mappings which should be added the graph\n  and will be used for example when serializing in a format with prefix support.\n  Defaults to the ones specified during the creation of the compound with `new/3`.\n- `:base_iri`: a base IRI which should be stored alongside the graph\n  and will be used for example when serializing in a format with base IRI support","ref":"RTC.Compound.html#unasserted_graph/2"},{"type":"type","title":"RTC.Compound.coercible_id/0","doc":"","ref":"RTC.Compound.html#t:coercible_id/0"},{"type":"type","title":"RTC.Compound.id/0","doc":"","ref":"RTC.Compound.html#t:id/0"},{"type":"type","title":"RTC.Compound.t/0","doc":"","ref":"RTC.Compound.html#t:t/0"},{"type":"module","title":"RTC.NS","doc":"`RDF.Vocabulary.Namespace`s for the used vocabularies.","ref":"RTC.NS.html"},{"type":"module","title":"RTC.NS.RTC","doc":"The RTC vocabulary.\n\nSince this module has the same basename as the top-level module, you can't\nalias it. Therefore, the top-level `RTC` module has delegators for all of the\nproperty functions in this module, so you can use them directly on the\ntop-level module without an alias.\n\nSee","ref":"RTC.NS.RTC.html"},{"type":"function","title":"RTC.NS.RTC.__iris__/0","doc":"Returns all known IRIs of the vocabulary.","ref":"RTC.NS.RTC.html#__iris__/0"},{"type":"function","title":"RTC.NS.RTC.element_of/0","doc":"","ref":"RTC.NS.RTC.html#element_of/0"},{"type":"function","title":"RTC.NS.RTC.element_of/1","doc":"`RDF.Description` property accessor for `element_of/0`","ref":"RTC.NS.RTC.html#element_of/1"},{"type":"function","title":"RTC.NS.RTC.element_of/2","doc":"`RDF.Description` builder for `element_of/0`","ref":"RTC.NS.RTC.html#element_of/2"},{"type":"function","title":"RTC.NS.RTC.elementOf/0","doc":"","ref":"RTC.NS.RTC.html#elementOf/0"},{"type":"function","title":"RTC.NS.RTC.elementOf/1","doc":"`RDF.Description` property accessor for `elementOf/0`","ref":"RTC.NS.RTC.html#elementOf/1"},{"type":"function","title":"RTC.NS.RTC.elementOf/2","doc":"`RDF.Description` builder for `elementOf/0`","ref":"RTC.NS.RTC.html#elementOf/2"},{"type":"function","title":"RTC.NS.RTC.elements/0","doc":"","ref":"RTC.NS.RTC.html#elements/0"},{"type":"function","title":"RTC.NS.RTC.elements/1","doc":"`RDF.Description` property accessor for `elements/0`","ref":"RTC.NS.RTC.html#elements/1"},{"type":"function","title":"RTC.NS.RTC.elements/2","doc":"`RDF.Description` builder for `elements/0`","ref":"RTC.NS.RTC.html#elements/2"},{"type":"function","title":"RTC.NS.RTC.sub_compound_of/0","doc":"","ref":"RTC.NS.RTC.html#sub_compound_of/0"},{"type":"function","title":"RTC.NS.RTC.sub_compound_of/1","doc":"`RDF.Description` property accessor for `sub_compound_of/0`","ref":"RTC.NS.RTC.html#sub_compound_of/1"},{"type":"function","title":"RTC.NS.RTC.sub_compound_of/2","doc":"`RDF.Description` builder for `sub_compound_of/0`","ref":"RTC.NS.RTC.html#sub_compound_of/2"},{"type":"function","title":"RTC.NS.RTC.subCompoundOf/0","doc":"","ref":"RTC.NS.RTC.html#subCompoundOf/0"},{"type":"function","title":"RTC.NS.RTC.subCompoundOf/1","doc":"`RDF.Description` property accessor for `subCompoundOf/0`","ref":"RTC.NS.RTC.html#subCompoundOf/1"},{"type":"function","title":"RTC.NS.RTC.subCompoundOf/2","doc":"`RDF.Description` builder for `subCompoundOf/0`","ref":"RTC.NS.RTC.html#subCompoundOf/2"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\nThis project adheres to [Semantic Versioning](http://semver.org/) and\n[Keep a CHANGELOG](http://keepachangelog.com).","ref":"changelog.html"},{"type":"extras","title":"v0.2.0 - 2024-08-07 - Changelog","doc":"This version upgrades to RDF.ex v2.0.","ref":"changelog.html#v0-2-0-2024-08-07"},{"type":"extras","title":"Added - Changelog","doc":"- `RTC.Compound.change_graph_name/1` which changes the graph name that will be \n  used in serializations to RDF (as opposed to `change_name/1` which, as an\n  alias of `reset_id/1`, also changes the id of the compound itself) \n\n\n[Compare v0.1.0...v0.2.0](https://github.com/rtc-org/rtc-ex/compare/v0.1.0...v0.2.0)","ref":"changelog.html#added"},{"type":"extras","title":"v0.1.0 - 2023-03-31 - Changelog","doc":"Initial release","ref":"changelog.html#v0-1-0-2023-03-31"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}